django-embed-video's documentation
==================================

Django app for easy embeding YouTube and Vimeo videos and music from SoundCloud.

Repository is located on GitHub: https://github.com/jazzband/django-embed-video



.. toctree::
   :maxdepth: 2
   :glob:

   installation
   examples
   example-project

   development/index 

   websites



Library API
###########

.. toctree::
   :maxdepth: 2

   api/index 



Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

